#!/bin/bash
#SBATCH --job-name=APPNAME_sim
#SBATCH --ntasks=32
#SBATCH --cpus-per-task=1
#SBATCH --out=./logs/simulations-%j.out
#SBATCH --err=./logs/simulations-%j.err
#SBATCH --time=23:00:00

module load musa/3.1

config_list="CONFIG_LIST"
app=APPNAME
args="APP_ARGUMENTS"
vector_list="SVE_REGISTER_SIZE_LIST"
greasy_name="greasy_${app}_${args//\ /_}.txt"
config_folder=./configs

rm $greasy_name
mkdir -p ${config_folder}

for configuration in $config_list; do
    for vector_length in $vector_list; do
        trace_name=trace_${vector_length}_${app}_${args//\ /_}/${app}_${vector_length}.ts
        log_file=./logs/simulation_big_${app}_${configuration}_noscaling_vec_${vector_length}.txt
        new_config="./${config_folder}/${configuration%%\.conf}_noscaling_vec_${vector_length}.conf"
        sed -e "s/SIMULATED_VECTOR/$vector_length/g" \
            -e "s/TRACE_VECTOR/$vector_length/g" <$configuration >${new_config}
        echo "tasksim $new_config $trace_name &>$log_file" >> $greasy_name
    done
done

for configuration in $config_list; do
    for vector_length in $vector_list; do
        trace_name=trace_128_${app}_${args//\ /_}/${app}_128.ts
        log_file=./logs/simulation_big_${app}_${configuration}_scaling_vec_${vector_length}.txt
        new_config="./${config_folder}/${configuration%%\.conf}_scaling_vec_${vector_length}.conf"
        sed -e "s/SIMULATED_VECTOR/$vector_length/g" \
            -e "s/TRACE_VECTOR/128/g" <$configuration >${new_config}
        echo "tasksim $new_config $trace_name &>$log_file" >> $greasy_name
    done
done

greasy $greasy_name
